@@ -36,7 +36,7 @@ function(Xamp, DT=0.008, STAMP=NULL)
     NSEL = 1
 
     ### get(getOption("device"))(width=15, height=10)
-       dev.new()
+       dev.new(width=15, height=10)
        
    ###  X11(width=15, height=10)
 ###  
